rotate_account_cryptographic_state

Function rotate_account_cryptographic_state 

pub(super) fn rotate_account_cryptographic_state(
    wrapped_account_cryptographic_state: &WrappedAccountCryptographicState,
    current_user_key_id: &SymmetricKeyId,
    new_user_key_id: &SymmetricKeyId,
    user_id: UserId,
    ctx: &mut KeyStoreContext<'_, KeyIds>,
) -> Result<AccountKeysRequestModel, ()>
Rotates an account cryptographic state and upgrades it to V2 if necessary. This function fails and logs an error via tracing if the passed keys are invalid, or if the account cryptographic state is malformed.