rotate_account_cryptographic_state_to_wrapped_model

Function rotate_account_cryptographic_state_to_wrapped_model 

pub(super) fn rotate_account_cryptographic_state_to_wrapped_model(
    wrapped_account_cryptographic_state: &WrappedAccountCryptographicState,
    current_user_key_id: &SymmetricKeySlotId,
    new_user_key_id: &SymmetricKeySlotId,
    ctx: &mut KeyStoreContext<'_, KeySlotIds>,
) -> Result<WrappedAccountCryptographicStateRequestModel, ()>
Rotates an account cryptographic state and upgrades it to V2 if necessary. This function fails and logs an error via tracing if the passed keys are invalid, or if the account cryptographic state is malformed.