pub(super) fn account_cryptographic_state_to_wrapped_model(
wrapped_account_cryptographic_state: &WrappedAccountCryptographicState,
new_user_key_id: &SymmetricKeySlotId,
ctx: &mut KeyStoreContext<'_, KeySlotIds>,
) -> Result<WrappedAccountCryptographicStateRequestModel, ()>Expand description
Converts a rotated account cryptographic state to a wrapped model for the request. This function fails and logs an error via tracing if the passed keys are invalid, or if the account cryptographic state is malformed.